/*
 * Copyright 2001-2003 Frey Technologies, LLC. All rights reserved.
 */
package sage;

// The plugin class must implement this interface
public interface EPGImportPlugin
{
	/*
	 * NOTE: In SageTV V1.2.8 this call is not implemented yet, it will retrieve this list from the SageTV server instead,
	 * but the EPG data will be retrieved using the plugin. It is implemented in V1.3 and higher.
	 * Returns a String[][2] for a given zip code. Each element pair represents a provider GUID & a provider name.
	 * These names will be displayed in the Setup Wizard for SageTV. The provider GUIDs must be valid arguments
	 * for Long.parseLong(providerID), represent positive numbers, and be consistent and unique for given provider.
	 * An example of the return value is:
	 * { { "1", "Test Lineup1"} {"2", "Test Lineup2"} }
	 */
	public String[][] getProviders(String zipCode);
	/*
	 * NOTE: In SageTV V1.2.8 this call is not implemented yet, it will retrieve this list from the SageTV server instead,
	 * but the EPG data will be retrieved using the plugin. It is implemented in V1.3 and higher.
	 * Returns a String[][2]. Each element pair represents a provider ID & a provider name.
	 * These names will be displayed in the Setup Wizard for SageTV if Local Markets are selected
	 * for the provider. The provider GUIDs must be valid arguments
	 * for Long.parseLong(providerID), represent positive numbers, and be consistent and unique for given provider.
	 * An example of the return value is:
	 * { { "3", "Test Local Lineup1"} {"4", "Test Local Lineup2"} }
	 */
	public String[][] getLocalMarkets();
	/*
	 * This is called daily (or more often if other events occur) to update the EPG database.
	 * It should return true if successful, and false if not. The providerID argument
	 * references the provider selected from the functions above. The EPGDBPublic object
	 * is what is used to make calls to the database to provide it with the new EPG information.
	 * See the documentation on EPGDBPublic for more information
	 */
	public boolean updateGuide(String providerID, EPGDBPublic dbInterface);
}
